@@ -1,8 +1,12 @@
 import urllib
+from typing import List, Optional
+
 import pandas as pd
 
 
-def flatten_dict_column(df, keys, col_name, add_col_prefix=True):
+def flatten_dict_column(
+    df: pd.DataFrame, keys: List[str], col_name: str, add_col_prefix: Optional[bool] = True
+) -> pd.DataFrame:
     """
     Extract the specified Pandas DataFrame dict column ('col_name'), creating new columns from the given keys.
     :param pd.DataFrame df: the Pandas DataFrame whose dict column will be flattened
@@ -11,18 +15,21 @@ def flatten_dict_column(df, keys, col_name, add_col_prefix=True):
     :param bool add_col_prefix: adds the original 'col_name' value as a prefix to generated columns if True
     :return: pd.DataFrame
     """
-    for key in keys:
-        if add_col_prefix is True:
-            df[col_name + '_' + key] = df[col_name].apply(lambda col: col[key])
-        elif add_col_prefix is False:
-            df[key] = df[col_name].apply(lambda col: col[key])
-        else:
-            raise ValueError("The 'add_col_prefix' value must be set to either True or False.")
-    df.drop(columns=[col_name], inplace=True)
-    return df
+    try:
+        for key in keys:
+            if add_col_prefix is True:
+                df[col_name + "_" + key] = df[col_name].apply(lambda col: col[key])
+            elif add_col_prefix is False:
+                df[key] = df[col_name].apply(lambda col: col[key])
+            else:
+                raise ValueError("The 'add_col_prefix' value must be set to either True or False.")
+        df.drop(columns=[col_name], inplace=True)
+        return df
+    except KeyError:
+        raise KeyError(f"No column named '{col_name}' was found in the DataFrame provided.")
 
 
-def flatten_dict_list_column(df, col_name):
+def flatten_dict_list_column(df: pd.DataFrame, col_name: str) -> pd.DataFrame:
     """
     Extract the dicts contained within the specified list column ('col_name'), creating new rows and columns.
     :param pd.DataFrame df: the Pandas DataFrame whose list of dicts (column) will be flattened
@@ -34,9 +41,9 @@ def flatten_dict_list_column(df, col_name):
         temp_df = pd.DataFrame(row[col_name])
         temp_df.index = [index] * temp_df.shape[0]
         flattened_col_df = flattened_col_df.append(temp_df)
-    new_df = df.drop(columns=[col_name]).join(flattened_col_df, how='inner')
+    new_df = df.drop(columns=[col_name]).join(flattened_col_df, how="inner")
     return new_df
 
 
-def get_server_netloc(server_address):
+def get_server_netloc(server_address: str):
     return urllib.parse.urlparse(server_address).netloc
